Files
TheRock/rocm-libraries/projects/hipfft/clients/samples/hipfft_2d_z2z.cpp
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

112 lines
3.9 KiB
C++

// Copyright (C) 2019 - 2026 Advanced Micro Devices, Inc. All rights
// reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
#include <complex>
#include <iostream>
#include <vector>
#include <hipfft/hipfft.h>
DISABLE_WARNING_PUSH
DISABLE_WARNING_DEPRECATED_DECLARATIONS
DISABLE_WARNING_RETURN_TYPE
#include <hip/hip_runtime_api.h>
DISABLE_WARNING_POP
int main()
{
std::cout << "hipfft 2D double-precision complex-to-complex transform\n";
const int Nx = 4;
const int Ny = 4;
int direction = HIPFFT_FORWARD; // forward=-1, backward=1
std::vector<std::complex<double>> cdata(Nx * Ny);
size_t complex_bytes = sizeof(decltype(cdata)::value_type) * cdata.size();
// Create HIP device object and copy data to device:
// hipfftComplex for single-precision
hipfftDoubleComplex* x;
hipError_t hip_rt = hipMalloc(&x, complex_bytes);
if(hip_rt != hipSuccess)
throw std::runtime_error("hipMalloc failed");
// Initialize the data
for(size_t i = 0; i < static_cast<size_t>(Nx) * Ny; i++)
{
cdata[i] = i;
}
std::cout << "input:\n";
for(size_t i = 0; i < static_cast<size_t>(Nx); i++)
{
for(size_t j = 0; j < static_cast<size_t>(Ny); j++)
{
size_t pos = i * Ny + j;
std::cout << cdata[pos] << " ";
}
std::cout << "\n";
}
std::cout << std::endl;
hip_rt = hipMemcpy(x, cdata.data(), complex_bytes, hipMemcpyHostToDevice);
if(hip_rt != hipSuccess)
throw std::runtime_error("hipMemcpy failed");
// Create plan (hipfftPlan2d internally allocates the handle)
hipfftHandle plan{};
hipfftResult hipfft_rt
= hipfftPlan2d(&plan, // plan handle
Nx, // transform length
Ny, // transform length
HIPFFT_Z2Z); // transform type (HIPFFT_C2C for single-precision)
if(hipfft_rt != HIPFFT_SUCCESS)
throw std::runtime_error("hipfftPlan2d failed");
// Execute plan
// hipfftExecZ2Z: double precision, hipfftExecC2C: for single-precision
hipfft_rt = hipfftExecZ2Z(plan, x, x, direction);
if(hipfft_rt != HIPFFT_SUCCESS)
throw std::runtime_error("hipfftExecZ2Z failed");
std::cout << "output:\n";
hip_rt = hipMemcpy(cdata.data(), x, complex_bytes, hipMemcpyDeviceToHost);
if(hip_rt != hipSuccess)
throw std::runtime_error("hipMemcpy failed");
for(size_t i = 0; i < static_cast<size_t>(Nx); i++)
{
for(size_t j = 0; j < static_cast<size_t>(Ny); j++)
{
auto pos = i * Ny + j;
std::cout << cdata[pos] << " ";
}
std::cout << "\n";
}
std::cout << std::endl;
if(hipfftDestroy(plan) != HIPFFT_SUCCESS)
throw std::runtime_error("hipfftDestroy failed");
hip_rt = hipFree(x);
if(hip_rt != hipSuccess)
throw std::runtime_error("hipFree failed");
return 0;
}